@@ -1,6 +1,5 @@
-context("HTML manipulation utilities")
-
 test_that("HTML unescaping is properly performed", {
+
   replace_attr("<img src='foo&#39;&xlarr;&BadEntity;bar.png'>", "img", "src", function(src) {
     expect_identical(src, "foo'\u27F5&BadEntity;bar.png")
     src
@@ -17,6 +16,7 @@ test_that("HTML unescaping is properly performed", {
 })
 
 test_that("HTML escaping is properly performed", {
+
   output <- replace_attr("<div title='foo.png'>", "div", "title", function(src) {
     "special chars '\"<>&"
   })
@@ -25,6 +25,7 @@ test_that("HTML escaping is properly performed", {
 })
 
 test_that("Newlines between attributes are OK", {
+
   output <- replace_attr("<h1\n\tclass='headline'>", "h1", "class", function(class) {
     NULL
   })
@@ -33,6 +34,7 @@ test_that("Newlines between attributes are OK", {
 })
 
 test_that("URL encoding is correctly decoded", {
+
   output <- inline_images("url_encoding.html")
   expect_true(grepl("data:image/png", output))
 
@@ -46,6 +48,7 @@ test_that("URL encoding is correctly decoded", {
 # TODO: Test for proper handling of file:// URLs
 
 test_that("WARNING: duplicate attribs are not supported correctly", {
+
   output <- replace_attr("<h1\n  class='headline' class='disabled'>", "h1", "class", function(class) {
     NULL
   })
@@ -54,6 +57,7 @@ test_that("WARNING: duplicate attribs are not supported correctly", {
 })
 
 test_that("File URI parsing works correctly", {
+
   # Illegal inputs
   expect_error(file_uri_to_filepath("http://example.com"))
   expect_error(file_uri_to_filepath("logo.gif"))
@@ -73,24 +77,27 @@ test_that("File URI parsing works correctly", {
 })
 
 test_that("src resolution works correctly", {
-  expect_equal(src_to_filepath("foo%20bar", "/baz"), "/baz/foo bar")
-  expect_equal(src_to_filepath("/foo%20bar", "/baz"), "/foo bar")
-  expect_equal(src_to_filepath("/foo%20bar", "/baz"), "/foo bar")
-  expect_equal(src_to_filepath("/foo%20bar", "."), "/foo bar")
+
+  expect_equal(as.character(src_to_filepath("foo%20bar", "/baz")), "/baz/foo bar")
+  expect_equal(as.character(src_to_filepath("/foo%20bar", "/baz")), "/foo bar")
+  expect_equal(as.character(src_to_filepath("/foo%20bar", "/baz")), "/foo bar")
+  expect_equal(as.character(src_to_filepath("/foo%20bar", ".")), "/foo bar")
 
   # Because of the potential for drive letters to be of
   # different cases, we transform the whole string to lower case
-  expect_equal(tolower(src_to_filepath("foo%20bar", ".")), tolower(file.path(getwd(), "foo bar")))
-  expect_equal(tolower(src_to_filepath("foo", "")), tolower(file.path(getwd(), "foo")))
+  expect_equal(tolower(as.character(src_to_filepath("foo%20bar", "."))), tolower(file.path(getwd(), "foo bar")))
+  expect_equal(tolower(as.character(src_to_filepath("foo", ""))), tolower(file.path(getwd(), "foo")))
+
+  expect_equal(as.character(src_to_filepath("../a/b", "/c/d")), "/c/a/b")
+  expect_equal(as.character(src_to_filepath("C:\\foo\\bar", "/baz")), "C:/foo/bar")
 
-  expect_equal(src_to_filepath("../a/b", "/c/d"), "/c/a/b")
-  expect_equal(src_to_filepath("C:\\foo\\bar", "/baz"), "C:/foo/bar")
   # Newer versions of fs capitalize drive letters
   expect_true(src_to_filepath("foo/bar", "c:\\baz") %in% c("c:/baz/foo/bar", "C:/baz/foo/bar"))
   expect_true(src_to_filepath("", "c:\\baz") %in% c("c:/baz", "C:/baz"))
 })
 
 test_that("decode_hex works correctly including for Unicode chars", {
+
   expect_identical(html_unescape("&#x51;"), "Q")
   expect_identical(html_unescape("&#81;"), "Q")
   expect_identical(html_unescape("&#x2661;"), "\u2661")
@@ -104,6 +111,7 @@ test_that("decode_hex works correctly including for Unicode chars", {
 })
 
 test_that("gfsub doesn't butcher line endings", {
+
   expect_identical(
     gfsub("a\nb\r\nc", "[\\w]", toupper),
     toupper("a\nb\r\nc")
@@ -111,17 +119,27 @@ test_that("gfsub doesn't butcher line endings", {
 })
 
 test_that("duplicate images are not attached multiple times", {
+
   img <- add_image(system.file(package = "blastula", "img/pexels-photo-267151.jpeg"))
   email <- compose_email(body = list(img, img))
+
   expect_identical(length(email$images), 1L)
 })
 
 test_that("HTML manipulation functions can handle large input", {
+
   big_value <- paste(collapse = "", rep_len("x", 5e7))
   big_html <- paste0("<img src=\"", big_value, "\"/> \u2600")
 
-  result <- replace_attr(big_html, "img", attr_name = "src", function(src) {
-    "hello \u2601"
-  })
+  result <-
+    replace_attr(
+      html = big_html,
+      tag_name = "img",
+      attr_name = "src",
+      func = function(src) {
+        "hello \u2601"
+      }
+    )
+
   expect_identical(result, "<img src=\"hello \u2601\"/> \u2600")
 })
